@@ -1086,7 +1086,7 @@ class LaharFlowData(object):
 
     def _valid_variable(self, variable):
         if variable not in _LFoutput_shortnames:
-            raise RuntimeError("variable {var} not recognized".format(var=variable))
+            raise RuntimeError(f"variable {variable} not recognized")
 
     def _extract_file(self, filename):
 
@@ -1327,7 +1327,7 @@ class LaharFlowData(object):
     def _get_max_bed_evolution(self):
         last_outfile = int(self.get_snapshot_files()[-1])
 
-        data = self.raster(last_outfile, var=["elevation_change"])
+        data = self.raster(last_outfile, vars=["elevation_change"])
 
         bt = data["elevation_change"].values
 
@@ -1375,7 +1375,7 @@ class LaharFlowData(object):
         last_outfile = self._snapshot_nc_files()[-1]
         LaharFlowFile = self._extract_file(last_outfile)
         try:
-            maxE, maxD = nc_min_max(LaharFlowFile, var="elevation_change")
+            maxE, maxD = nc_min_max(LaharFlowFile, vars="elevation_change")
             self.MaxDeposit = maxD["elevation_change"]
             # self.MaxErosion = -maxE['elevation_change']
         except:
@@ -1534,9 +1534,7 @@ class LaharFlowData(object):
 
         if var not in valid_vars:
             raise ValueError(
-                "variable name must be one of {names}, received '{var}'".format(
-                    names=valid_vars, var=var
-                )
+                f"variable name must be one of {valid_vars}, received '{var}'"
             )
 
         dat = dataset[var]
@@ -1729,7 +1727,7 @@ class LaharFlowData(object):
         if filename is not None:
             data = self.raster(
                 filename,
-                var=var,
+                vars=var,
                 full_domain=full_domain,
                 nodata=np.nan,
                 masked=True,
@@ -1820,7 +1818,7 @@ class LaharFlowData(object):
         if filename is not None:
             data = self.raster(
                 filename,
-                var=var,
+                vars=var,
                 full_domain=full_domain,
                 nodata=np.nan,
                 masked=True,
@@ -1897,7 +1895,7 @@ class LaharFlowData(object):
 
         fmt = _get_LF_output_fmt(variable, filetype=filetype)
 
-        raster = self.raster(result, var=[variable], crs=crs, nodata=np.nan)
+        raster = self.raster(result, vars=[variable], crs=crs, nodata=np.nan)
 
         data = raster[variable].data
         x = raster[variable].x
